@@ -11,7 +11,8 @@ import datetime
 from peewee import (AutoField, BigIntegerField, DateTimeField,
                     DeferredThroughModel, DoubleField,
                     FloatField, ForeignKeyField, IntegerField,
-                    ManyToManyField, Select, TextField, fn)
+                    ManyToManyField, BooleanField,
+                    Select, TextField, fn)
 from playhouse.postgres_ext import ArrayField
 
 import sdssdb.peewee.sdss5db.targetdb as targetdb
@@ -47,8 +48,8 @@ class FieldToPriority(OpsdbBase):
                                     column_name='field_priority_pk',
                                     field='pk')
     field = ForeignKeyField(targetdb.Field,
-                            column_name='field_id',
-                            field='field_id')
+                            column_name='field_pk',
+                            field='pk')
 
     class Meta:
         table_name = 'field_to_priority'
@@ -101,6 +102,7 @@ class DesignToStatus(OpsdbBase):
                              column_name='completion_status_pk',
                              field='pk')
     mjd = FloatField()
+    manual = BooleanField(default=False)
 
     class Meta:
         table_name = 'design_to_status'
@@ -232,11 +234,9 @@ class Queue(OpsdbBase):
         if isinstance(design, targetdb.Design):
             design = design.design_id
         Select(columns=[fn.appendQueue(design, mjd_plan)]).execute(database)
-        # queue_db = Queue.get(design=design)
-        # return queue_db
 
     @classmethod
-    def insertInQueue(cls, design, position, exp_length=None):
+    def insertInQueue(cls, design, position, exp_length=None, mjd=None):
         """exp_length in days
            this is the amount added to every mjd_plan AFTER position
         """
@@ -249,9 +249,8 @@ class Queue(OpsdbBase):
             design = design.design_id
         Select(columns=[fn.insertInQueue(design,
                                          position,
-                                         exp_length)]).execute(database)
-        # queue_db = Queue.get(design=design)
-        # return queue_db
+                                         exp_length,
+                                         mjd)]).execute(database)
 
     @classmethod
     def flushQueue(cls):
@@ -266,15 +265,15 @@ class Queue(OpsdbBase):
         """
 
         if isinstance(field, targetdb.Field):
-            field_id = field.field_id
+            field_pk = field.field_pk
         else:
-            field_id = field
+            field_pk = field
 
         rm_designs = cls.select()\
                         .join(targetdb.Design,
                               on=(targetdb.Design.design_id == cls.design_id))\
                         .join(targetdb.Field)\
-                        .where(targetdb.Field.field_id == field_id)
+                        .where(targetdb.Field.pk == field_pk)
 
         positions = [d.position for d in rm_designs]
         pos = max(positions)
